@@ -6,4 +6,7 @@ from .core import (
     compute_prob_mat,
     entropy_score,
     find_k,
-)
\ No newline at end of file
+)
+
+from .repeated import *
+from .model_selection import *
\ No newline at end of file
